#!/bin/bash
# Get Linux distribution name
get_os_distribution() {
    if   [ -e /etc/debian_version ] ||
         [ -e /etc/debian_release ]; then
        # Check Ubuntu or Debian
        if [ -e /etc/lsb-release ]; then
            # Ubuntu
            distri_name="ubuntu"
			cat /etc/lsb-release > os
        else
            # Debian
            distri_name="debian"
			cat /etc/debian_version > os
        fi
    elif [ -e /etc/fedora-release ]; then
        # Fedra
        distri_name="fedora"
		cat /etc/fedora-release > os
    elif [ -e /etc/redhat-release ]; then
        if [ -e /etc/oracle-release ]; then
            # Oracle Linux
            distri_name="oracle"
			cat /etc/oracle-release > os
        else
            # Red Hat Enterprise Linux
            distri_name="redhat"
			cat /etc/redhat-release > os
        fi
    elif [ -e /etc/arch-release ]; then
        # Arch Linux
        distri_name="arch"
		cat /etc/arch-release > os
    elif [ -e /etc/turbolinux-release ]; then
        # Turbolinux
        distri_name="turbol"
		cat /etc/turbolinux-release > os
    elif [ -e /etc/SuSE-release ]; then
        # SuSE Linux
        distri_name="suse"
		cat /etc/SuSE-release > os
    elif [ -e /etc/mandriva-release ]; then
        # Mandriva Linux
        distri_name="mandriva"
		cat /etc/mandriva-release > os
    elif [ -e /etc/vine-release ]; then
        # Vine Linux
        distri_name="vine"
		cat /etc/vine-release > os
    elif [ -e /etc/gentoo-release ]; then
        # Gentoo Linux
        distri_name="gentoo"
		cat /etc/gentoo-release > os
    else
        # Other
        echo "unkown distribution"
        distri_name="unkown"
		cat /etc/system-release > os
    fi

    echo ${distri_name}
}

get_installtime() {
	if type rpm 2>/dev/null 1>/dev/null; then
		rpm -q basesystem --qf='%{installtime}\n' > os_install_1
	elif type repoquery 2>/dev/null 1>/dev/null; then
		repoquery -q basesystem --installed --qf='%{installtime}' > os_install_1
	fi

	ls -alct --time-style=+%Y%m%d%H%M%S / |tail -1|awk '{print $6}' > os_install_2
	
	# echo installtime
}

get_app() {
	if type dpkg-query 2>/dev/null 1>/dev/null; then
		dpkg-query --show -f '${binary:Package}.${Architecture} ${version} ${binary:Package}:${Architecture}\n' > app
		grep " install " /var/log/dpkg.log > app_install
	elif type repoquery 2>/dev/null 1>/dev/null; then
		repoquery --all --pkgnarrow=installed --qf="%{name}.%{arch}  %{version}-%{release} %{installtime}" > app
	else
		rpm -qa --qf="%{name}.%{arch}  %{version}-%{release} %{installtime}\n" > app
	fi
	
	# echo app
}

check_dmi(){
	if [ -e /sys/devices/virtual/dmi/id/sys_vendor ]; then
		if [ -e /sys/devices/virtual/dmi/id/product_name ]; then
			if [ -e /sys/devices/virtual/dmi/id/product_serial ]; then
				if [ -e /sys/devices/virtual/dmi/id/product_uuid ]; then
					echo "1"
				fi
			fi
		fi
    fi
	
	echo "0"
}

check_cmd(){
	cmd=$1
	if type $cmd 2>/dev/null 1>/dev/null; then
		return 1
	else
		return 0
	fi
}

cmd_msg(){
	cmd=$1
	if type $cmd 2>/dev/null 1>/dev/null; then
		return 1
	else
		echo "コマンド「${cmd}」がインストールされていません"
		echo "インストール後に再度実行してください"
		exit
	fi
}

file_msg(){
	file=$1
	if [ -e $file ]; then
		return 1
	else
		echo "コマンド「${cmd}」がインストールされていません"
		echo "インストール後に再度実行してください"
		exit
	fi
}

DMI=0
if [ -e /sys/devices/virtual/dmi/id/sys_vendor ]; then
	if [ -e /sys/devices/virtual/dmi/id/product_name ]; then
		if [ -e /sys/devices/virtual/dmi/id/product_serial ]; then
			if [ -e /sys/devices/virtual/dmi/id/product_uuid ]; then
				DMI=1
			fi
		fi
	fi
fi
check_cmd dmidecode
DMIC=$?

if [ $DMI = 0 -a $DMIC = 0 ]; then
	echo "コマンド「dmidecode」がインストールされていません"
	echo "インストール後に再度実行してください"
	exit
fi

cmd_msg hostname
cmd_msg domainname
cmd_msg ls
cmd_msg getconf
file_msg /proc/cpuinfo
file_msg /proc/meminfo
cmd_msg lsblk
cmd_msg df
cmd_msg lspci
cmd_msg udevadm
cmd_msg ip
cmd_msg lsblk

check_cmd dpkg-query
DPKG=$?
check_cmd repoquery
REPO=$?
check_cmd rpm
RPM=$?
if [ $DPKG = 0 -a $REPO = 0 -a $RPM = 0 ]; then
	echo "コマンド「dpkg-query」「repoquery」「rpm」がインストールされていません"
	echo "インストール後に再度実行してください"
	exit
fi

if [ ! -e result ]; then
	mkdir result
fi
cd result


dmidecode -t system | egrep "Manufacturer|Product Name|Serial Number|UUID|^$" > dmidecode
grep -R --no-message ''  /sys/devices/virtual/dmi/id/ > grep_sys_devices

hostname > hostname
domainname > domainname

get_os_distribution

get_installtime

getconf LONG_BIT > arch

egrep "physical id|model name|cpu cores|cpu MHz|^$" /proc/cpuinfo > cpu
grep "MemTotal" /proc/meminfo > mem
lsblk -o type,model,size,kname -P -b > physical_disk
df -T -x tmpfs -B1 -l > logical_disk
lspci -nn | grep VGA > video

NICS=($(ls -1 /sys/class/net))
for nic in ${NICS[@]}; do
  udevadm info --query=property --path=/sys/class/net/$nic > nic_$nic
  ip addr show dev $nic > ip_$nic
done

get_app

exit
